@@ -1,4 +1,4 @@
-use serde_repr::{Serialize_repr, Deserialize_repr};
+use serde_repr::{Deserialize_repr, Serialize_repr};
 
 #[derive(Debug, Clone, Serialize_repr, Deserialize_repr, PartialEq)]
 #[repr(u8)]
@@ -17,7 +17,7 @@ impl UserTier {
             None => 0,
             One => 50,
             Two => 100,
-            Three => 250
+            Three => 250,
         }
     }
-}
\ No newline at end of file
+}
