@@ -1,4 +1,4 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 use twilight_cache_inmemory::model::CachedGuild;
 
 #[derive(Serialize, Deserialize)]
