@@ -1,5 +1,6 @@
 pub use backup::*;
 pub use chatlog::*;
+pub use copy::*;
 pub use guild::*;
 pub use response::*;
 pub use sync::*;
@@ -8,6 +9,7 @@ pub use user::*;
 
 mod backup;
 mod chatlog;
+mod copy;
 mod guild;
 mod response;
 mod sync;
