@@ -1,4 +1,4 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct TemplateMetaWire {
@@ -12,7 +12,7 @@ pub struct TemplateMetaWire {
     pub user_upvoted: bool,
     pub tags: Vec<String>,
     pub language: Option<String>,
-    pub internal: bool
+    pub internal: bool,
 }
 
 #[derive(Serialize, Deserialize)]
