@@ -1,4 +1,4 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 
 use crate::UserTier;
 
@@ -10,7 +10,7 @@ pub struct UserWire {
     pub avatar: Option<String>,
     pub public_flags: u64,
     pub internal_flags: u32,
-    pub tier: UserTier
+    pub tier: UserTier,
 }
 
 impl Default for UserTier {
@@ -18,4 +18,3 @@ impl Default for UserTier {
         Self::None
     }
 }
-
